aboutsummaryrefslogtreecommitdiffstats
path: root/mitmproxy/controller.py
diff options
context:
space:
mode:
authorluz.paz <luzpaz@users.noreply.github.com>2018-02-24 21:45:11 -0500
committerluz.paz <luzpaz@users.noreply.github.com>2018-02-24 21:45:11 -0500
commitafbb7f117b8be34e35735e4b4b1244ee5c5bbae1 (patch)
tree0af5f0598251973f5921c4cf42c4403f40ff9065 /mitmproxy/controller.py
parent6b5b71aefaffebeea9eb0003a25f039686c5b785 (diff)
downloadmitmproxy-afbb7f117b8be34e35735e4b4b1244ee5c5bbae1.tar.gz
mitmproxy-afbb7f117b8be34e35735e4b4b1244ee5c5bbae1.tar.bz2
mitmproxy-afbb7f117b8be34e35735e4b4b1244ee5c5bbae1.zip
Misc. typos
Found via `codespell -q 3 -I ../mitmproxy-word-whitelist.txt` Where whitelist contains: ``` cas doubleclick nd ot seeked statics te thru ```
Diffstat (limited to 'mitmproxy/controller.py')
-rw-r--r--mitmproxy/controller.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/mitmproxy/controller.py b/mitmproxy/controller.py
index f39c1b24..beb210ca 100644
--- a/mitmproxy/controller.py
+++ b/mitmproxy/controller.py
@@ -56,7 +56,7 @@ class Reply:
self._state = "start" # "start" -> "taken" -> "committed"
# Holds the reply value. May change before things are actually commited.
self.value = NO_REPLY
@property
@@ -66,7 +66,7 @@ class Reply:
sequentially through the following lifecycle:
1. start: Initial State.
- 2. taken: The reply object has been taken to be commited.
+ 2. taken: The reply object has been taken to be committed.
3. committed: The reply has been sent back to the requesting party.
This attribute is read-only and can only be modified by calling one of
@@ -91,7 +91,7 @@ class Reply:
def commit(self):
"""
Ultimately, messages are commited. This is done either automatically by
if the message is not taken or manually by the entity which called
.take().
"""
@@ -56,7 +56,7 @@ class Reply:
self._state = "start" # "start" -> "taken" -> "committed"
- # Holds the reply value. May change before things are actually commited.
+ # Holds the reply value. May change before things are actually committed.
self.value = NO_REPLY
@@ -91,7 +91,7 @@ class Reply:
def commit(self):
"""
- Ultimately, messages are commited. This is done either automatically by
+ Ultimately, messages are committed. This is done either automatically by
if the message is not taken or manually by the entity which called
.take().